@@ -16,7 +16,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '1.1136'
+    return '2.1.0'
 
 
 def f_debug():
@@ -33,7 +33,8 @@ def f_debug():
     ----
 
     """
-    from Fishconsole import logs, files, helps, Fishsys
+    global main, smtp授权码, threading, os
+    from Fishconsole import logs, files, Fishsys
     try:
         import os, pandas as pd
         from openpyxl.utils import get_column_letter
@@ -44,9 +45,9 @@ def f_debug():
     except:
         logs.安全退出("fcv依赖包导入出错，程序无法运行")
 
-
     def to_excel_auto_column_weight(df: pd.DataFrame, writer: ExcelWriter, sheet_name):
         """DataFrame保存为excel并自动设置列宽"""
+        global ExcelWriter, pd
         df.to_excel(writer, sheet_name=sheet_name, index=False)
         #  计算表头的字符宽度
         column_widths = (
@@ -99,7 +100,7 @@ def f_debug():
 
 
 
-        elif b[0] in ["cls","CLS"]:
+        elif b[0] in ["cls", "CLS"]:
             # 这一条是搞那种cls不能用的情况，如果它能用的话cls了谁也不知道干了啥
             print("\n" * 30)
             os.system("cls")
@@ -107,7 +108,7 @@ def f_debug():
 
 
 
-        elif b[0] in ["view","VIEW"]:
+        elif b[0] in ["view", "VIEW"]:
             未选触发器 = True
             for a in b:
                 # 循环检测
@@ -127,10 +128,10 @@ def f_debug():
                         "PI": "passworld系统日志输出控制",
                         "HEI": "helps主程序系统日志输出开关",
                         "ZUI": "字符串转unicode模块系统日志输出开关",
-                        'AC':"系统自动存储的smtp授权码",
-                        'FHUM':"first help updata message",
-                        'FESA':'系统自动存储的邮件发送账号',
-                        'Sender':'系统自动存储的发件人姓名'
+                        'AC': "系统自动存储的smtp授权码",
+                        'FHUM': "first help updata message",
+                        'FESA': '系统自动存储的邮件发送账号',
+                        'Sender': '系统自动存储的发件人姓名'
 
                     }
                     变量组classification = {
@@ -145,10 +146,10 @@ def f_debug():
                         "PI": "系统日志",
                         "HEI": "系统日志",
                         "ZUI": "系统日志",
-                        "AC":"邮件",
-                        'FHUM':'help弹窗',
-                        'FESA':"邮件",
-                        'Sender':'邮件'
+                        "AC": "邮件",
+                        'FHUM': 'help弹窗',
+                        'FESA': "邮件",
+                        'Sender': '邮件'
                     }
                     变量组classification = pd.DataFrame(变量组classification.items(), columns=['name', "classification"])
                     变量组info = pd.DataFrame(变量组info.items(), columns=['name', "info about"])
@@ -162,8 +163,10 @@ def f_debug():
 
                         with pd.ExcelWriter(r'Fishconsole.fcc.xlsx') as writer:
                             to_excel_auto_column_weight(res, writer, f'Fishconsole fcv_debug变量组')
+
                         def start():
                             os.system("Fishconsole.fcc.xlsx")
+
                         a = threading.Thread(target=start)
                         a.start()
                     except:
@@ -182,11 +185,11 @@ def f_debug():
 
 
 
-        elif b[0] in ["exit","EXIT"]:
+        elif b[0] in ["exit", "EXIT"]:
             logs.安全退出("fcv_debug正常退出")
 
 
-        elif b[0] in ["change","CHANGE"]:
+        elif b[0] in ["change", "CHANGE"]:
             未选触发器 = True
             for a in b:
                 # 循环检测
@@ -195,7 +198,7 @@ def f_debug():
                     变量组 = files.缓存(2)
                     if 变量组:
                         mod = 变量组.get("Forcedupdate")
-                        if mod == True:
+                        if mod:
                             变量组["Forcedupdate"] = False
                             files.缓存(1, 变量组)
                             print(logs.日志("操作成功", "绿色"))
@@ -217,7 +220,7 @@ def f_debug():
                     变量组 = files.缓存(2)
                     if 变量组:
                         mod = 变量组.get("UPI")
-                        if mod == True:
+                        if mod:
                             变量组["UPI"] = False
                             files.缓存(1, 变量组)
                             print(logs.日志("操作成功", "绿色"))
@@ -239,7 +242,7 @@ def f_debug():
                     变量组 = files.缓存(2)
                     if 变量组:
                         mod = 变量组.get("FI")
-                        if mod == True:
+                        if mod:
                             变量组["FI"] = False
                             files.缓存(1, 变量组)
                             print(logs.日志("操作成功", "绿色"))
@@ -261,7 +264,7 @@ def f_debug():
                     变量组 = files.缓存(2)
                     if 变量组:
                         mod = 变量组.get("PI")
-                        if mod == True:
+                        if mod:
                             变量组["PI"] = False
                             files.缓存(1, 变量组)
                             print(logs.日志("操作成功", "绿色"))
@@ -283,7 +286,7 @@ def f_debug():
                     变量组 = files.缓存(2)
                     if 变量组:
                         mod = 变量组.get("HEI")
-                        if mod == True:
+                        if mod:
                             变量组["HEI"] = False
                             files.缓存(1, 变量组)
                             print(logs.日志("操作成功", "绿色"))
@@ -305,7 +308,7 @@ def f_debug():
                     变量组 = files.缓存(2)
                     if 变量组:
                         mod = 变量组.get("ZUI")
-                        if mod == True:
+                        if mod:
                             变量组["ZUI"] = False
                             files.缓存(1, 变量组)
                             print(logs.日志("操作成功", "绿色"))
@@ -322,21 +325,19 @@ def f_debug():
                         files.缓存(1, 变量组)
                         break
 
-                if a in  ["AC","ac"]:
+                if a in ["AC", "ac"]:
                     未选触发器 = False
-                    计数器=0
+                    计数器 = 0
                     try:
-                        smtp授权码=b[2]
+                        smtp授权码 = b[2]
                     except:
-                        print(logs.日志("参数缺失","红色"))
+                        print(logs.日志("参数缺失", "红色"))
                     try:
-                        files.缓存(3,数据={"AC":smtp授权码})
+                        files.缓存(3, 数据={"AC": smtp授权码})
                         print(logs.日志("操作成功", "绿色"))
-                        logs.变量查看("smtp授权码",smtp授权码)
+                        logs.变量查看("smtp授权码", smtp授权码)
                     except:
-                        logs.日志("未知错误","红色")
-
-
+                        logs.日志("未知错误", "红色")
 
             if 未选触发器:
                 print(logs.分割线(f"这是change的简介", "fcv_debug console", 色选="红色"))
@@ -346,8 +347,8 @@ def f_debug():
                 print("如果想了解具体的用法，请在终端中键入'help'或者'?'")
 
 
-        elif b[0] in ["version", "VERSION","V","v"]:
-            print(logs.日志(f"Fishconsole fcv_debug [ 2.0 ]","蓝色"))
+        elif b[0] in ["version", "VERSION", "V", "v"]:
+            print(logs.日志(f"Fishconsole fcv_debug [ 2.0 ]", "蓝色"))
 
 
         elif b[0] in ["pip", "PIP"]:
@@ -355,19 +356,19 @@ def f_debug():
             for a in b:
                 # 循环检测
                 if a == "install":
-                    print(logs.日志("Fishconsole fcv_debug PIP》安装和更新开始","蓝色"))
+                    print(logs.日志("Fishconsole fcv_debug PIP》安装和更新开始", "蓝色"))
                     未选触发器 = False
-                    res=Fishsys.官网存活性检测("https://pypi.org/",3)
+                    res = Fishsys.官网存活性检测("https://pypi.org/", 3)
                     if res:
                         try:
-                            main(['install', '--upgrade','pip'])
-                            main(['install',f'{b[2]}'])
-                            main(['install', '--upgrade' , f'{b[2]}'])
+                            main(['install', '--upgrade', 'pip'])
+                            main(['install', f'{b[2]}'])
+                            main(['install', '--upgrade', f'{b[2]}'])
                         except:
-                            print(logs.日志("Fishconsole fcv_debug PIP》未知错误","蓝色"))
+                            print(logs.日志("Fishconsole fcv_debug PIP》未知错误", "蓝色"))
                         print(logs.日志("Fishconsole fcv_debug PIP》安装和更新结束", "蓝色"))
                     else:
-                        print(logs.日志("官网连接失败","红色"))
+                        print(logs.日志("官网连接失败", "红色"))
                         print(logs.日志("Fishconsole fcv_debug PIP》安装和更新结束", "蓝色"))
             if 未选触发器:
                 print(logs.分割线(f"这是pip的简介", "fcv_debug console", 色选="红色"))
@@ -379,28 +380,29 @@ def f_debug():
 
 
 
-        elif b[0] in ["help", "?", "？","HELP"]:
+        elif b[0] in ["help", "?", "？", "HELP"]:
             def 帮助():
                 from Fishconsole import helps
                 helps.帮助()
+
             helps_res = threading.Thread(target=帮助)
             helps_res.start()
-        elif b[0] in ["updata","UPDATA"]:
-            print(logs.日志("Fcv_debug Console》我们将尝试激活更新，在程序执行完毕以后，我们将阻止强制更新系统在下一次继续运行","蓝色"))
-            files.缓存(3,数据={'updata':True})
+        elif b[0] in ["updata", "UPDATA"]:
+            print(logs.日志("Fcv_debug Console》我们将尝试激活更新，在程序执行完毕以后，我们将阻止强制更新系统在下一次继续运行", "蓝色"))
+            files.缓存(3, 数据={'updata': True})
             Fishsys.Fishconsole_Update()
             files.缓存(3, 数据={'updata': False})
 
         elif b[0] in ["execute"]:
             未选触发器 = True
-            空容器=""
-            计数器=0
+            空容器 = ""
+            计数器 = 0
             for temp in b[1:]:
-                if 计数器==0:
-                    空容器=空容器+" "+temp
+                if 计数器 == 0:
+                    空容器 = 空容器 + " " + temp
                 else:
-                    空容器=" "+空容器+" "+temp
-            if not 空容器=="":
+                    空容器 = " " + 空容器 + " " + temp
+            if not 空容器 == "":
                 未选触发器 = False
                 os.system(空容器)
             if 未选触发器:
