@@ -13,6 +13,9 @@ from Fishconsole import fcv
 # 显示行列要用
 import signal
 
+#显示编码要用
+import chardet
+
 
 
 
@@ -169,20 +172,25 @@ def 变量查看(变量名: str, 变量, 色选: str = "红色",自动换行=Fal
     计数器 = 计数器 + 22 + 计数器a
     if 计数器>=100:
         计数器=100
-    print(计数器)
 
     print("=" * 计数器)
-    print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）"))
-    if 变量类型 in ["numpy.ndarray","torch.Tensor"]:
+    print(日志(f"  ||（{颜色('名字', 色选)}：{变量名}）"))
+    if 变量类型 in ["numpy.ndarray","torch.Tensor","pandas.core.frame.DataFrame"]:
         print(日志(f"  ||（{颜色('数据', 色选)}：\n{变量}\n）"))
     else:
         print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
     print(日志(f"  ||（{颜色('类型', 色选)}: {变量类型}）"))
-    print(日志(f"  ||（{颜色('位置', 色选)}:{行位置}）"))
+    print(日志(f"  ||（{颜色('位置', 色选)}: {行位置}）"))
+
+    try:
+        print(日志(f"  ||（{颜色('编码', 色选)}: {chardet.detect(变量)['encoding']} / {chardet.detect(变量)['confidence']}）"))
+    except:
+        print(日志(f"  ||（{颜色('编码', 色选)}: 未知 / 未知）"))
 
     print("=" * 计数器 + "\n\n")
 
 
+
 def 安全退出(内容, 变量=None):
     """
         FishConsole LOGS安全退出
@@ -200,8 +208,8 @@ def 安全退出(内容, 变量=None):
         sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
 
     else:
-        变量查看("temp", 变量)
-        os.kill(os.getpid(),signal.SIGKILL)
+        变量查看("用户所指定的数据", 变量)
+
         sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
 
 
