@@ -6,13 +6,14 @@
 ----
 
 """
-import datetime
 
-模块开始 = datetime.datetime.now()
-
-import easygui
-# 虽然没什么用，但是里面的强制更新系统可以很好的牵制调用
 from Fishconsole import files,logs,fcv
+try:
+    import easygui
+    import datetime
+except:
+    logs.安全退出("window依赖包导入出错，程序无法运行")
+
 
 
 
@@ -79,6 +80,10 @@ def 文件保存():
     返回 = easygui.filesavebox()
     return 返回
 
+def 文件夹选择():
+    返回 = easygui.diropenbox()
+    return 返回
+
 
 # 弹窗(1,2,3)
 # print(选择对话框(1,2,选项=["ab","cd","ef"],图片地址="h.PNG"))
